from setuptools import setup

setup(
  name='omni_reports',
  packages=['omni_reports'],
  version='0.0.1',
  description='Omni Report Definition',
  author='Pareto Group',
  author_email='noreply@paretogroup.com.br',
  url='https://github.com/paretogroup/omni-reports',
  keywords=['pareto', 'api', 'reports'],
  classifiers=[],
)
